==> generator-copado-1.0.6.tgz: package/generators/app/index.js <==
var Generator = require('yeoman-generator');

module.exports = class extends Generator {
    async prompting() {
        this.props = await this.prompt([
            // {
            //     type: "input",
            //     name: "tsurl",
            //     message: "Please list your salesforce deployment environments separated by commas. \r\n " +
            //         "Example: qa,stage,pre-production,production \r\n" +
            //         "The first environment you input will be the default enviorment.",
            //     default: "qa,stage,pre-prod,prod"
            // },
            {
                type: "input",
                name: "tsurl",
                message: "salesfore login url",
                default: "https://login.salesforce.com/"
            },
            {
                type: "input",
                name: "username",
                message: "username"
            },
            {
                type: "input",
                name: "password",
                message: "password"
            },
            {
                type: "input",
                name: "token",
                message: "security token"
            },
            {
                type: "list",
                name: "mode",
                message: "testrail mode",
                choices: ["lightning", "classic"]
            }
        ]);
    }

    getProjectPath() {
        var paths = process.cwd().split("\\").join("/").split("/");
        return paths[paths.length - 1];
    }

    // writting() {
    //   this.log(this.props.name);
    //   this.log(this.props.tsurl);
    //   this.log(this.props.username);
    //   this.log(this.props.password);
    //   this.log(this.props.token);
    //   this.log(this.props.mode);
    // }

    //Writing Logic here
    writing() {
        //Copy the configuration files
        config: {
            this.fs.copyTpl(
                this.templatePath('_package.json'),
                this.destinationPath('package.json'), {
                    name: this.getProjectPath()
                }
            );
            this.fs.copyTpl(
                this.templatePath('_cypress.json'),
                this.destinationPath('cypress.json'), {
                    name: this.getProjectPath()
                }
            );
            this.fs.copyTpl(
                this.templatePath('_cypress.env.json'),
                this.destinationPath('cypress.env.json'), {
                    tsurl: this.props.tsurl,
                    username: this.props.username,
                    password: this.props.password,
                    token: this.props.token,
                    mode: this.props.mode,
                }
            );
        }

        //Copy application files
        app: {
            this.fs.copyTpl(
                this.templatePath('cypress/integration/_salesforce_sample_spec.js'),
                this.destinationPath('cypress/integration/salesforce_sample_spec.js')
            );
        }
        //Install Dependencies
    }
};

==> generator-copado-1.0.7.tgz: package/generators/app/index.js <==
var Generator = require('yeoman-generator');

module.exports = class extends Generator {
    async prompting() {
        this.props = await this.prompt([
            // {
            //     type: "input",
            //     name: "tsurl",
            //     message: "Please list your salesforce deployment environments separated by commas. \r\n " +
            //         "Example: qa,stage,pre-production,production \r\n" +
            //         "The first environment you input will be the default enviorment.",
            //     default: "qa,stage,pre-prod,prod"
            // },
            {
                type: "input",
                name: "tsurl",
                message: "salesfore login url",
                default: "https://login.salesforce.com/"
            },
            {
                type: "input",
                name: "username",
                message: "username"
            },
            {
                type: "input",
                name: "password",
                message: "password"
            },
            {
                type: "input",
                name: "token",
                message: "security token"
            },
            {
                type: "list",
                name: "mode",
                message: "testrail mode",
                choices: ["lightning", "classic"]
            }
        ]);
    }

    getProjectPath() {
        var paths = process.cwd().split("\\").join("/").split("/");
        return paths[paths.length - 1];
    }

    // writting() {
    //   this.log(this.props.name);
    //   this.log(this.props.tsurl);
    //   this.log(this.props.username);
    //   this.log(this.props.password);
    //   this.log(this.props.token);
    //   this.log(this.props.mode);
    // }

    //Writing Logic here
    writing() {
        //Copy the configuration files
        config: {
            this.fs.copyTpl(
                this.templatePath('_package.json'),
                this.destinationPath('package.json'), {
                    name: this.getProjectPath()
                }
            );
            this.fs.copyTpl(
                this.templatePath('_cypress.json'),
                this.destinationPath('cypress.json'), {
                    name: this.getProjectPath()
                }
            );
            this.fs.copyTpl(
                this.templatePath('_cypress.env.json'),
                this.destinationPath('cypress.env.json'), {
                    tsurl: this.props.tsurl,
                    username: this.props.username,
                    password: this.props.password,
                    token: this.props.token,
                    mode: this.props.mode,
                }
            );
        }

        //Copy application files
        app: {
            this.fs.copyTpl(
                this.templatePath('cypress/integration/_copado_saleforce_sample_spec.js'),
                this.destinationPath('cypress/integration/copado_saleforce_sample_spec.js')
            );
            this.fs.copyTpl(
                this.templatePath('cypress/integration/_testrail_sample_spec.js'),
                this.destinationPath('cypress/integration/testrail_sample_spec.js')
            );
        }
        //Install Dependencies
    }
};
